<!--
Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com

This work is licensed under the Creative Commons Attribution-ShareAlike 4.0
International License. To view a copy of this license, visit
http://creativecommons.org/licenses/by-sa/4.0/ or send a letter to Creative
Commons, PO Box 1866, Mountain View, CA 94042, USA.
-->

<!--
Changelog titles are:
- Added: for new features.
- Changed: for changes in existing functionality.
- Deprecated: for soon-to-be removed features.
- Removed: for now removed features.
- Fixed: for any bug fixes.
- Security: in case of vulnerabilities.
-->

# Changelog

All notable changes of this project will be documented here.

The format is based on
[Keep a Changelog](https://keepachangelog.com/en/1.0.0)
and this project adheres to
[Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Version 2.0.3 (October 2025)

### Removed

- Support for python 3.9.

### Fixed

- Fixed an issue with the `PDFO_COBYLA_Settings` class that prevented the algorithm from being initialized correctly.

## Version 2.0.2 (September 2025)

### Fixed

- The default value of the `normalize_design_space` setting.

## Version 2.0.1 (August 2025)

### Added

- Support PDFO v2.2.0.

## Version 2.0.0 (November 2024)

### Added

- Support GEMSEO v6.
- Support for Python 3.12.

## Version 1.0.1 (December 2023)

### Added

- Support for Python 3.11.

### Removed

- Support for Python 3.8.

## Version 1.0.0 (June 2023)

First version.
